summaryrefslogtreecommitdiffstats
path: root/konversation/src/nicksonline.h
diff options
context:
space:
mode:
Diffstat (limited to 'konversation/src/nicksonline.h')
-rw-r--r--konversation/src/nicksonline.h68
1 files changed, 34 insertions, 34 deletions
diff --git a/konversation/src/nicksonline.h b/konversation/src/nicksonline.h
index 6243b78..9dcf7f0 100644
--- a/konversation/src/nicksonline.h
+++ b/konversation/src/nicksonline.h
@@ -20,14 +20,14 @@
#include "chatwindow.h"
#include "linkaddressbook/nicksonlinetooltip.h"
-#include <qvbox.h>
-#include <qiconset.h>
-#include <qpair.h>
+#include <tqvbox.h>
+#include <tqiconset.h>
+#include <tqpair.h>
class KListView;
-class QPushButton;
-class QPopupMenu;
+class TQPushButton;
+class TQPopupMenu;
class ChatWindow;
@@ -60,12 +60,12 @@ class NicksOnline : public ChatWindow
nsHasAddress = 2 // Nick has an associated addressbook entry.
};
- explicit NicksOnline(QWidget* parent);
+ explicit NicksOnline(TQWidget* parent);
~NicksOnline();
// These are here for the benefit of NicksOnlineTooltip.
KListView* getNickListView();
- NickInfoPtr getNickInfo(const QListViewItem* item);
+ NickInfoPtr getNickInfo(const TQListViewItem* item);
virtual bool canBeFrontView() { return true; }
@@ -77,7 +77,7 @@ class NicksOnline : public ChatWindow
/**
* Emitted whenever user double-clicks a nick in the Nicks Online tab.
*/
- void doubleClicked(const QString& server,const QString& nick);
+ void doubleClicked(const TQString& server,const TQString& nick);
void showView(ChatWindow* view);
@@ -94,7 +94,7 @@ class NicksOnline : public ChatWindow
* When a user double-clicks a nickname in the nicklistview, let server know so that
* it can perform the user's chosen default action for that.
*/
- void processDoubleClick(QListViewItem* item);
+ void processDoubleClick(TQListViewItem* item);
/**
* Timer used to refresh display.
*/
@@ -118,7 +118,7 @@ class NicksOnline : public ChatWindow
/**
* Received when right-clicking an item in the NickListView.
*/
- void slotNickListView_RightButtonClicked(QListViewItem* item, const QPoint& pt);
+ void slotNickListView_RightButtonClicked(TQListViewItem* item, const TQPoint& pt);
/**
* Received from server when a NickInfo changes its information.
*/
@@ -136,24 +136,24 @@ class NicksOnline : public ChatWindow
/**
* Returns the named child of parent item in a NicksOnlineItem
* @param parent Pointer to a NicksOnlineItem.
* @param name The name in the desired child QListViewItem, must be in column 0.
* @param type The type of entry to be found
* @return Pointer to the child QListViewItem or 0 if not found.
*/
- QListViewItem* findItemChild(const QListViewItem* parent, const QString& name, NicksOnlineItem::NickListViewColumn type);
+ TQListViewItem* findItemChild(const TQListViewItem* parent, const TQString& name, NicksOnlineItem::NickListViewColumn type);
/**
* Returns the first occurrence of a child item of a given type in a NicksOnlineItem
* @param parent Pointer to a NicksOnlineItem.
* @param type The type of entry to be found
* @return Pointer to the child QListViewItem or 0 if not found.
*/
- QListViewItem* findItemType(const QListViewItem* parent, NicksOnlineItem::NickListViewColumn type);
+ TQListViewItem* findItemType(const TQListViewItem* parent, NicksOnlineItem::NickListViewColumn type);
/**
* Returns a pointer to the network QListViewItem with the given name.
* @param name The name of the network, assumed to be in column 0 of the item.
* @return Pointer to the QListViewItem or 0 if not found.
*/
- QListViewItem* findNetworkRoot(const QString& name);
+ TQListViewItem* findNetworkRoot(const TQString& name);
/**
* Refresh the nicklistview for all servers.
*/
@@ -162,7 +162,7 @@ class NicksOnline : public ChatWindow
* Refreshes the information for the given item in the list.
* @param item Pointer to listview item.
*/
- void refreshItem(QListViewItem* item);
+ void refreshItem(TQListViewItem* item);
/**
* Return a string containing formatted additional information about a nick.
* @param nickInfo A pointer to NickInfo structure for the nick.
@@ -171,31 +171,31 @@ class NicksOnline : public ChatWindow
* @return needWhois True if a WHOIS needs to be performed on the nick
* to get additional information.
*/
- QString getNickAdditionalInfo(NickInfoPtr nickInfo, KABC::Addressee addressee,
+ TQString getNickAdditionalInfo(NickInfoPtr nickInfo, KABC::Addressee addressee,
bool& needWhois);
/**
* Invokes the KAddressBook contact editor for the specified contact id.
* @param uid Id of the contact.
* @return False if unable to invoke the Contact editor.
*/
- bool editAddressee(const QString &uid);
+ bool editAddressee(const TQString &uid);
/**
* Returns the server name and nickname of the specified nicklistview item.
* @param item The nicklistview item.
* @return serverName Name of the server for the nick at the item, or Null if not a nick.
* @return nickname The nickname at the item.
*/
- bool getItemServerAndNick(const QListViewItem* item, QString& serverName, QString& nickname);
+ bool getItemServerAndNick(const TQListViewItem* item, TQString& serverName, TQString& nickname);
/**
* Given a server name and nickname, returns the item in the Nick List View displaying
* the nick.
* @param serverName Name of server.Server
* @param nickname Nick name.
* @return Pointer to QListViewItem displaying the nick, or 0 if not found.
*
* @see getItemServerAndNick
*/
- QListViewItem* getServerAndNickItem(const QString& serverName, const QString& nickname);
+ TQListViewItem* getServerAndNickItem(const TQString& serverName, const TQString& nickname);
/**
* Perform an addressbook command (edit contact, create new contact,
* change/delete association.)
@@ -214,7 +214,7 @@ class NicksOnline : public ChatWindow
* @return Addressbook state.
* 0 = not a nick, 1 = nick has no addressbook association, 2 = nick has association
*/
- int getNickAddressbookState(QListViewItem* item);
+ int getNickAddressbookState(TQListViewItem* item);
/**
* Sets the enabled/disabled state and labels of the addressbook buttons
* based on the given nick addressbook state.
@@ -229,31 +229,31 @@ class NicksOnline : public ChatWindow
* @param nickname Nick name.
* @return NickInfo if nick is online in any server, otherwise 0.
*/
- NickInfoPtr getOnlineNickInfo(QString& networkName, QString& nickname);
+ NickInfoPtr getOnlineNickInfo(TQString& networkName, TQString& nickname);
/**
* Requests a WHOIS for a specified server network and nickname.
* The request is sent to the first server found in the network.
* @param groupName Server group name.
* @param nickname Nick name.
*/
- void requestWhois(QString& networkName, QString& nickname);
+ void requestWhois(TQString& networkName, TQString& nickname);
// The main display of networks, nicks, and channels.
KListView* m_nickListView;
// Buttons on screen.
- QPushButton* m_editContactButton;
- QPushButton* m_changeAssociationButton;
- QPushButton* m_deleteAssociationButton;
+ TQPushButton* m_editContactButton;
+ TQPushButton* m_changeAssociationButton;
+ TQPushButton* m_deleteAssociationButton;
// Context menu when right-clicking a nick.
- QPopupMenu* m_popupMenu;
+ TQPopupMenu* m_popupMenu;
// Helper to display tooltip information for nicks.
Konversation::KonversationNicksOnlineToolTip *m_tooltip;
// A string containing the identifier for the "Offline" listview item
- QString c_offline;
+ TQString c_offline;
// Timer for refreshing display and generating WHOISes.
- QTimer* m_timer;
+ TQTimer* m_timer;
// Addressbook icon.
- QIconSet m_kabcIconSet;
+ TQIconSet m_kabcIconSet;
/* Set to False every 8 seconds so that we generate a WHOIS on watch nicks that
lack information.*/
bool m_whoisRequested;
@@ -136,24 +136,24 @@ class NicksOnline : public ChatWindow
* Returns the named child of parent item in a NicksOnlineItem
* @param parent Pointer to a NicksOnlineItem.
- * @param name The name in the desired child QListViewItem, must be in column 0.
+ * @param name The name in the desired child TQListViewItem, must be in column 0.
* @param type The type of entry to be found
@@ -136,24 +136,24 @@ class NicksOnline : public ChatWindow
* @param type The type of entry to be found
- * @return Pointer to the child QListViewItem or 0 if not found.
+ * @return Pointer to the child TQListViewItem or 0 if not found.
*/
@@ -136,24 +136,24 @@ class NicksOnline : public ChatWindow
* @param parent Pointer to a NicksOnlineItem.
* @param type The type of entry to be found
- * @return Pointer to the child QListViewItem or 0 if not found.
+ * @return Pointer to the child TQListViewItem or 0 if not found.
*/
@@ -136,24 +136,24 @@ class NicksOnline : public ChatWindow
/**
- * Returns a pointer to the network QListViewItem with the given name.
+ * Returns a pointer to the network TQListViewItem with the given name.
* @param name The name of the network, assumed to be in column 0 of the item.
@@ -136,24 +136,24 @@ class NicksOnline : public ChatWindow
* @param name The name of the network, assumed to be in column 0 of the item.
- * @return Pointer to the QListViewItem or 0 if not found.
+ * @return Pointer to the TQListViewItem or 0 if not found.
*/
@@ -171,31 +171,31 @@ class NicksOnline : public ChatWindow
* @param serverName Name of server.Server
* @param nickname Nick name.
- * @return Pointer to QListViewItem displaying the nick, or 0 if not found.
+ * @return Pointer to TQListViewItem displaying the nick, or 0 if not found.
*
* @see getItemServerAndNick